@@ -83,7 +83,7 @@ impl Terminal {
 
     #[inline]
     pub fn to_index(&self, x: usize, y: usize) -> usize {
-        y * self.width() + x
+        y.wrapping_mul(self.width()) + x
     }
 
     #[inline]
@@ -151,6 +151,14 @@ impl Terminal {
         }
     }
 
+    pub fn put_fg_color(&mut self, x: usize, y: usize, col: Color) {
+        self.get_tile_mut(x, y).fg_color = col;
+    }
+
+    pub fn put_bg_color(&mut self, x: usize, y: usize, col: Color) {
+        self.get_tile_mut(x, y).bg_color = col;
+    }
+
     pub fn get_char(&self, x: usize, y: usize) -> char {
         self.get_tile(x, y).glyph
     }
